@@ -3,6 +3,7 @@ import os
 import sys
 import re
 
+
 class Config(object):
     DEFAULTS = {
         "LOGGING_LEVEL_CONSOLE": logging.INFO,  # See documentation of Logging package
@@ -70,8 +71,9 @@ class Config(object):
         "SYNC_TIME_MIN_DRIFT": (
                 120,
                 int,
-                (60, 0xFFFFFFFF)
+                (120, 0xFFFFFFFF)
         ), # Minimum time drift in seconds to initiate time sync
+        "SYNC_TIME_TIMEZONE": "",  # By default pai uses the same timezone as pai host
         "PASSWORD": (
             None,
             [int, str, bytes, type(None)],
@@ -99,6 +101,9 @@ class Config(object):
         "MQTT_USERNAME": (None, [str, type(None)]),  # MQTT Username for authentication
         "MQTT_PASSWORD": (None, [str, type(None)]),  # MQTT Password
         "MQTT_RETAIN": True,  # Publish messages with Retain
+        "MQTT_QOS": (0, int, (0, 2)),  # Publish messages with QOS level (0 - fire and forget, 1 - at least once, 2 - exactly once)
+        "MQTT_PROTOCOL": ("3.1.1", str, ("3.1", "3.1.1", "5")),  # Protocol to use
+        "MQTT_TRANSPORT": ("tcp", str, ("tcp", "websockets")),  # Transport to use
         "MQTT_BIND_ADDRESS": "",  # MQTT Bind address (Paho default)
         "MQTT_BIND_PORT": 0,  # MQTT Bind port (Paho default)
         "MQTT_REPUBLISH_INTERVAL": (
@@ -107,6 +112,7 @@ class Config(object):
             (60, 0xFFFFFFFF),
         ),  # Interval for republishing all data
         "MQTT_HOMEASSISTANT_AUTODISCOVERY_ENABLE": False,
+        "MQTT_HOMEASSISTANT_CODE": (None, [str, type(None)]),
         # MQTT Topics
         "MQTT_BASE_TOPIC": "paradox",  # Root of all topics
         "MQTT_ZONE_TOPIC": "zones",  # Base for zone states
@@ -165,11 +171,19 @@ class Config(object):
             str,
             ["DEBUG", "INFO", "WARN", "ERROR", "CRITICAL"],
         ),
+        "HOMEASSISTANT_PUBLISH_PARTITION_PROPERTIES": [  # List of partition properties to publish
+            'target_state',
+            'current_state'
+        ],
+        "HOMEASSISTANT_PUBLISH_ZONE_PROPERTIES": [  # List of zone properties to publish
+            'open',
+            'tamper'
+        ],
         "HOMEASSISTANT_NOTIFICATIONS_IGNORE_EVENTS": [],  # List of tuples or regexp matching "type,label,property=value,property2=value" eg. [(major, minor), "zone:HOME:entry_delay=True", ...]
         "HOMEASSISTANT_NOTIFICATIONS_ALLOW_EVENTS": [],  # Same as before but as a white list. Default is use EVENT_FILTERS
         "HOMEASSISTANT_NOTIFICATIONS_EVENT_FILTERS": [  # list of tags, property changes to include or exclude. See event.py for tag list
             "live,alarm,-restore",
-            "live,trouble,-clock",
+            "trouble,-clock",
             "live,tamper",
         ],
         # Pushbullet
@@ -181,7 +195,7 @@ class Config(object):
         "PUSHBULLET_ALLOW_EVENTS": [],  # Same as before but as a white list. Default is use EVENT_FILTERS
         "PUSHBULLET_EVENT_FILTERS": [  # list of tags, property changes to include or exclude. See event.py for tag list
             "live,alarm,-restore",
-            "live,trouble,-clock",
+            "trouble,-clock",
             "live,tamper",
         ],
         "PUSHBULLET_MIN_EVENT_LEVEL": (
@@ -199,7 +213,7 @@ class Config(object):
         "PUSHOVER_ALLOW_EVENTS": [],  # Same as before but as a white list. Default is use EVENT_FILTERS
         "PUSHOVER_EVENT_FILTERS": [  # list of tags, property changes to include or exclude. See event.py for tag list
             "live,alarm,-restore",
-            "live,trouble,-clock",
+            "trouble,-clock",
             "live,tamper",
         ],
         "PUSHOVER_MIN_EVENT_LEVEL": (
@@ -214,7 +228,7 @@ class Config(object):
         "SIGNAL_ALLOW_EVENTS": [],  # Same as before but as a white list. Default is use EVENT_FILTERS
         "SIGNAL_EVENT_FILTERS": [  # list of tags, property changes to include or exclude. See event.py for tag list
             "live,alarm,-restore",
-            "live,trouble,-clock",
+            "trouble,-clock",
             "live,tamper",
         ],
         "SIGNAL_MIN_EVENT_LEVEL": (
@@ -251,7 +265,8 @@ class Config(object):
         "DUMMY_EVENT_FILTERS": [
             "live,alarm-restore",
             "live,trouble-clock",
-            "live,tamper" "live,arm",
+            "live,tamper",
+            "live,arm",
             "live,disarm",
         ],
         "DUMMY_MIN_EVENT_LEVEL": (
@@ -271,80 +286,19 @@ class Config(object):
             + dir(super(Config, self))
         )
 
+    def __init__(self):
+        self._reset_defaults()
+
     def load(self, alt_location=None):
         self.CONFIG_LOADED = False
 
-        env_config_path = os.environ.get("PAI_CONFIG_FILE")
-
-        if alt_location is not None:
-            locations = [alt_location]
-        elif env_config_path:
-            locations = [env_config_path]
-        else:
-            filenames = ["pai.conf", "pai.json", "pai.yaml"]
-            locations = [
-                os.path.join(dir, filename)
-                for dir in [
-                    os.path.realpath(os.getcwd()),
-                    os.path.expanduser("~/.local/etc"),
-                    "/etc/pai",
-                    "/usr/local/etc/pai",
-                ]
-                for filename in filenames
-            ]
-
-        for location in locations:
-            location = os.path.expanduser(location)
-            if os.path.exists(location) and os.path.isfile(location):
-                self.CONFIG_FILE_LOCATION = location
-                break
-        else:
-            err = f"ERROR: Could not find configuration file. Tried: {locations}"
-            sys.stderr.write(err + "\n")
-            raise (Exception(err))
+        self._find_config(alt_location)
 
         sys.stdout.write(
             "Attempting to load configuration from %s\n" % self.CONFIG_FILE_LOCATION
         )
-
-        entries = {}
-        conf_extension = os.path.splitext(self.CONFIG_FILE_LOCATION)[1]
-        if conf_extension in [".conf", ".py"]:
-            with open(self.CONFIG_FILE_LOCATION) as f:
-                exec(f.read(), None, entries)
-        elif conf_extension in [".json"]:
-            import json
-
-            with open(self.CONFIG_FILE_LOCATION) as f:
-                entries = json.load(f)
-        elif conf_extension in [".yaml"]:
-            import yaml
-
-            with open(self.CONFIG_FILE_LOCATION) as f:
-                entries = yaml.safe_load(f)
-        else:
-            err = "ERROR: Unsupported configuration file type"
-            sys.stderr.write(err + "\n")
-            raise (Exception(err))
-
-        # Updates values from env variables
-        for args in os.environ:
-            if not args.startswith("PAI_") or len(args) < 5:
-                continue
-            opt = args[4:]
-            if opt in self.DEFAULTS:
-                v = os.environ[args]
-                if v.isdigit():
-                    v = int(v)
-
-                entries[opt] = v
-
-        # Reset defaults
-        for k, v in self.DEFAULTS.items():
-            if isinstance(v, tuple):
-                v = v[0]
-
-            setattr(self, k, v)
+        entries = self._read_config()
+        self._update_from_environment(entries)
 
         # Set values
         for k, v in entries.items():
@@ -397,6 +351,78 @@ class Config(object):
 
         self.CONFIG_LOADED = True
 
+    def _update_from_environment(self, entries):
+        # Updates values from env variables
+        for args in os.environ:
+            if not args.startswith("PAI_") or len(args) < 5:
+                continue
+            opt = args[4:]
+            if opt in self.DEFAULTS:
+                v = os.environ[args]
+                if v.isdigit():
+                    v = int(v)
+
+                entries[opt] = v
+
+    def _read_config(self):
+        entries = {}
+        conf_extension = os.path.splitext(self.CONFIG_FILE_LOCATION)[1]
+        if conf_extension in [".conf", ".py"]:
+            with open(self.CONFIG_FILE_LOCATION) as f:
+                exec(f.read(), None, entries)
+        elif conf_extension in [".json"]:
+            import json
+
+            with open(self.CONFIG_FILE_LOCATION) as f:
+                entries = json.load(f)
+        elif conf_extension in [".yaml"]:
+            import yaml
+
+            with open(self.CONFIG_FILE_LOCATION) as f:
+                entries = yaml.safe_load(f)
+        else:
+            err = "ERROR: Unsupported configuration file type"
+            sys.stderr.write(err + "\n")
+            raise (Exception(err))
+        return entries
+
+    def _find_config(self, alt_location):
+        env_config_path = os.environ.get("PAI_CONFIG_FILE")
+        if alt_location is not None:
+            locations = [alt_location]
+        elif env_config_path:
+            locations = [env_config_path]
+        else:
+            filenames = ["pai.conf", "pai.json", "pai.yaml"]
+            locations = [
+                os.path.join(dir, filename)
+                for dir in [
+                    os.path.realpath(os.getcwd()),
+                    os.path.expanduser("~/.local/etc"),
+                    "/etc/pai",
+                    "/usr/local/etc/pai",
+                ]
+                for filename in filenames
+            ]
+        for location in locations:
+            location = os.path.expanduser(location)
+            if os.path.exists(location) and os.path.isfile(location):
+                self.CONFIG_FILE_LOCATION = location
+                break
+        else:
+            err = f"ERROR: Could not find configuration file. Tried: {locations}"
+            sys.stderr.write(err + "\n")
+            raise (Exception(err))
+
+    def _reset_defaults(self):
+        # Reset defaults
+        for k, v in self.DEFAULTS.items():
+            if isinstance(v, tuple):
+                v = v[0]
+
+            setattr(self, k, v)
+
+
 config = Config()
 
 comma_splitter_re = re.compile('\s*,\s*')
@@ -431,4 +457,4 @@ def get_limits_for_type(elem_type: str, default: list = None):
     if isinstance(limits, str):
         if "auto" in limits:
             return default
-        return string_to_id_list(limits)
\ No newline at end of file
+        return string_to_id_list(limits)
