@@ -558,6 +558,7 @@ event_map = {
             19: dict(message="IP Module Supervision Loss"),
             20: dict(message="Fail To Communicate IP Receiver 1 (IP)"),
             21: dict(message="Fail To Communicate IP Receiver 2 (IP)"),
+            23: dict(message="Panel tamper supervision"),
             99: dict(message="Any new trouble event"),
         },
     ),
@@ -591,6 +592,7 @@ event_map = {
             19: dict(message="IP Module Supervision Loss restore"),
             20: dict(message="Fail To Communicate IP Receiver 1 (IP) restore"),
             21: dict(message="Fail To Communicate IP Receiver 2 (IP) restore"),
+            23: dict(message="Panel tamper supervision restore"),
             99: dict(message="Any trouble event restore"),
         },
     ),
